@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -116,10 +116,16 @@ int main(int argc, char **argv)
       kernel = cosc;
     else if (strcmp(s, "cot") == 0)
       kernel = kcot;
+    else if (strcmp(s, "one_over_cube") == 0)
+      kernel = one_over_cube;
+    else if (strcmp(s, "log_sin") == 0)
+      kernel = log_sin;
+    else if (strcmp(s, "laplacian_rbf") == 0)
+      kernel = laplacian_rbf;
     else
     {
-      s = "multiquadric";
-      kernel = multiquadric;
+      printf("Unrecognized kernel function!\n");
+      exit(EXIT_FAILURE);
     }
   }
   printf(
@@ -205,7 +211,7 @@ int main(int argc, char **argv)
   fid2 = fopen("f_direct.dat", "w+");
   if (fid1 == NULL)
   {
-    printf("Fehler!\n");
+    printf("Error writing to file f.dat!\n");
     exit(EXIT_FAILURE);
   }
   for (j = 0; j < M; j++)
