@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -51,8 +51,8 @@ static void reconstruct(char* filename,int N,int M,int iteration, int weight)
   my_N[1]=N; my_n[1]=ceil(N*alpha);
   nfft_init_guru(&my_plan, 2, my_N, M, my_n, m, PRE_PHI_HUT| PRE_PSI|
                          MALLOC_X| MALLOC_F_HAT| MALLOC_F|
-                         FFTW_INIT| FFT_OUT_OF_PLACE,
-                         FFTW_MEASURE| FFTW_DESTROY_INPUT);
+                         FFTW_INIT,
+                         FFTW_MEASURE);
 
   /* precompute lin psi if set */
   if(my_plan.flags & PRE_LIN_PSI)
