@@ -50,8 +50,8 @@ static void reconstruct(char* filename,int N,int M,int Z, int weight ,fftw_compl
   my_N[1]=N; my_n[1]=ceil(N*1.2);
   nfft_init_guru(&my_plan, 2, my_N, M/Z, my_n, 6, PRE_PHI_HUT| PRE_PSI|
                         MALLOC_X| MALLOC_F_HAT| MALLOC_F|
-                        FFTW_INIT| FFT_OUT_OF_PLACE,
-                        FFTW_MEASURE| FFTW_DESTROY_INPUT);
+                        FFTW_INIT,
+                        FFTW_MEASURE);
 
   /* precompute lin psi if set */
   if(my_plan.flags & PRE_LIN_PSI)
