@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Copyright (c) 2003, 2006 Matteo Frigo
 # Copyright (c) 2003, 2006 Massachusetts Institute of Technology
@@ -19,9 +19,8 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 ################################################################################
-# NOTE: If you just want to build NFFT3, do not use this file. Just follow the 
-# installation instructions as described in the tutorial found under 
-# doc/tutorial.
+# NOTE: If you just want to build NFFT3, do not use this file. Just follow the
+# installation instructions in README.md.
 #
 # This file is based on the bootstrap.sh script from FFTW 3.1.2 by
 # M. Frigo and S. G. Johnson
@@ -32,13 +31,8 @@ alias libtoolize=$(type -p glibtoolize libtoolize | head -1)
 
 touch ChangeLog
 
-echo "PLEASE IGNORE WARNINGS AND ERRORS"
-
-# paranoia: sometimes autoconf doesn't get things right the first time
 rm -rf autom4te.cache
 libtoolize
 autoreconf --verbose --install --force
-autoreconf --verbose --install --force
-autoreconf --verbose --install --force
 
 rm -f config.cache
