@@ -78,16 +78,10 @@
 
 /***************************************************************************/
 
-#if TIME_WITH_SYS_TIME
+#if HAVE_SYS_TIME_H
 # include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
 #endif
+#include <time.h>
 
 #define INLINE_ELAPSED(INL) static INL double elapsed(ticks t1, ticks t0) \
 {                                     \
