@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -16,7 +16,7 @@
  * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/*! \file infft3.h
+/*! \file infft.h
  *  \brief Internal header file for auxiliary definitions and functions.
  */
 #ifndef __INFFT_H__
@@ -53,7 +53,7 @@
 #include "ticks.h"
 
 /**
- * @defgroup nfftutil Util - Auxilliary functions
+ * @defgroup nfftutil Util - Auxiliary functions
  * @{
  *
  * This module implements frequently used utility functions.
@@ -1247,20 +1247,20 @@ extern double _Complex catanh(double _Complex z);
 #endif
 
 #if defined(NFFT_LDOUBLE)
-  #define EPSILON LDBL_EPSILON//4.0E-31L
   #define MANT_DIG LDBL_MANT_DIG
   #define MIN_EXP LDBL_MIN_EXP
   #define MAX_EXP LDBL_MAX_EXP
+  #define EPSILON LDBL_EPSILON
 #elif defined(NFFT_SINGLE)
-  #define EPSILON FLT_EPSILON
   #define MANT_DIG FLT_MANT_DIG
   #define MIN_EXP FLT_MIN_EXP
   #define MAX_EXP FLT_MAX_EXP
+  #define EPSILON FLT_EPSILON
 #else
-  #define EPSILON DBL_EPSILON
   #define MANT_DIG DBL_MANT_DIG
   #define MIN_EXP DBL_MIN_EXP
   #define MAX_EXP DBL_MAX_EXP
+  #define EPSILON DBL_EPSILON
 #endif
 
 #if defined(FLT_ROUND)
@@ -1431,7 +1431,7 @@ R Y(bsplines)(const INT, const R x);
 /* float.c: */
 typedef enum {NFFT_EPSILON = 0, NFFT_SAFE__MIN = 1, NFFT_BASE = 2,
   NFFT_PRECISION = 3, NFFT_MANT_DIG = 4, NFFT_FLTROUND = 5, NFFT_E_MIN = 6,
-  NFFT_R_MIN = 7, NFFT_E_MAX = 8, NFFT_R_MAX = 9} float_property;
+  NFFT_R_MIN = 7, NFFT_E_MAX = 8, NFFT_R_MAX = 9 } float_property;
 
 R Y(float_property)(float_property);
 R Y(prod_real)(R *vec, INT d);
