@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -30,7 +30,7 @@ extern "C"
 #define NFFT_CONCAT(prefix, name) prefix ## name
 
 /* IMPORTANT: for Windows compilers, you should add a line
- *   #define FFTW_DLL
+ *   #define NFFT_DLL
  * here and in kernel/infft.h if you are compiling/using NFFT as a DLL, in order
  * to do the proper importing/exporting, or alternatively compile with
  * -DNFFT_DLL or the equivalent command-line flag. This is not necessary under
@@ -144,7 +144,7 @@ typedef struct\
   Y(plan) my_fftw_plan2; /**< Backward FFTW plan */\
 \
   R **c_phi_inv; /**< Precomputed data for the diagonal matrix \f$D\f$, size \
-    is \f$N_0+\hdots+N_{d-1}\f$ doubles*/\
+    is \f$N_0+\dots+N_{d-1}\f$ doubles*/\
   R *psi; /**< Precomputed data for the sparse matrix \f$B\f$, size depends
                     on precomputation scheme */\
   NFFT_INT *psi_index_g; /**< Indices in source/target vector for \ref PRE_FULL_PSI */\
@@ -610,6 +610,7 @@ NFSFT_DEFINE_API(NFSFT_MANGLE_LONG_DOUBLE,NFFT_MANGLE_LONG_DOUBLE,long double,ff
 #define NFSFT_DESTROY_F_HAT  (1U << 10)
 #define NFSFT_DESTROY_X      (1U << 11)
 #define NFSFT_DESTROY_F      (1U << 12)
+#define NFSFT_EQUISPACED     (1U << 17)
 
 /* precompute flags */
 #define NFSFT_NO_DIRECT_ALGORITHM (1U << 13)
@@ -660,6 +661,7 @@ FPT_DEFINE_API(FPT_MANGLE_LONG_DOUBLE,FFTW_MANGLE_LONG_DOUBLE,long double,fftwl_
 #define FPT_NO_FAST_ALGORITHM   (1U << 2)
 #define FPT_NO_DIRECT_ALGORITHM (1U << 3)
 #define FPT_PERSISTENT_DATA     (1U << 4)
+#define FPT_NO_INIT_FPT_DATA    (1U << 7)
 
 /* transform flags */
 #define FPT_FUNCTION_VALUES     (1U << 5)
@@ -685,17 +687,15 @@ typedef struct X(plan_)\
 {\
   MACRO_MV_PLAN(C) \
   R *x; /**< input nodes */\
-  C *wig_coeffs; /**< contains a set of SO(3) Fourier coefficients for fixed
-    orders m and n*/\
-  C *cheby; /**< contains a set of Chebychev coefficients for fixed orders m
-    and n*/\
-  C *aux; /**< used when converting Chebychev to Fourier coeffcients*/\
   /* internal use only */\
-  int t; /**< the logaritm of NPT with respect to the basis 2 */\
+  C *wig_coeffs; /**< deprecated variable */\
+  C *cheby; /**< deprecated variable */\
+  C *aux; /**< deprecated variable */\
+  int t; /**< the logarithm of NPT with respect to the basis 2 */\
   unsigned int flags; /**< the planner flags  */\
   Y(plan) p_nfft; /**< the internal NFFT plan */\
-  Z(set) internal_fpt_set; /**< the internal FPT plan */\
-  int fpt_kappa; /**a parameter controlling the accuracy of the FPT*/\
+  Z(set) *internal_fpt_set; /**< the internal FPT plan */\
+  int nthreads; /**< the number of threads */\
 } X(plan);\
 \
 NFFT_EXTERN void X(precompute)(X(plan) *plan); \
@@ -705,6 +705,7 @@ NFFT_EXTERN void X(SO3_fpt_transposed)(C *coeffs, Z(set) set,int l, int k, int m
 NFFT_EXTERN void X(init)(X(plan) *plan, int N, int M); \
 NFFT_EXTERN void X(init_advanced)(X(plan) *plan, int N, int M,unsigned int nfsoft_flags); \
 NFFT_EXTERN void X(init_guru)(X(plan) *plan, int N, int M,unsigned int nfsoft_flags,unsigned int nfft_flags,int nfft_cutoff,int fpt_kappa); \
+NFFT_EXTERN void X(init_guru_advanced)(X(plan) *plan, int N, int M,unsigned int nfsoft_flags,unsigned int nfft_flags,int nfft_cutoff,int fpt_kappa, int nn_oversampled); \
 NFFT_EXTERN void X(trafo)(X(plan) *plan_nfsoft); \
 NFFT_EXTERN void X(adjoint)(X(plan) *plan_nfsoft); \
 NFFT_EXTERN void X(finalize)(X(plan) *plan); \
@@ -738,7 +739,6 @@ NFSOFT_DEFINE_API(NFSOFT_MANGLE_LONG_DOUBLE,NFFT_MANGLE_LONG_DOUBLE,FPT_MANGLE_L
 
 /* helper macros */
 #define NFSOFT_INDEX(m,n,l,B) (((l)+((B)+1))+(2*(B)+2)*(((n)+((B)+1))+(2*(B)+2)*((m)+((B)+1))))
-#define NFSOFT_INDEX_TWO(m,n,l,B) ((B+1)*(B+1)+(B+1)*(B+1)*(m+B)-((m-1)*m*(2*m-1)+(B+1)*(B+2)*(2*B+3))/6)+(posN(n,m,B))+(l-MAX(ABS(m),ABS(n)))
 #define NFSOFT_F_HAT_SIZE(B) (((B)+1)*(4*((B)+1)*((B)+1)-1)/3)
 
 /* solver */
@@ -859,6 +859,8 @@ void Y(vpr_double)(R *x, const NFFT_INT n, const char *text); \
 void Y(vpr_complex)(C *x, const NFFT_INT n, const char *text); \
 /* thread.c */ \
 NFFT_INT Y(get_num_threads)(void); \
+void Y(set_num_threads)(NFFT_INT nthreads); \
+NFFT_INT Y(has_threads_enabled)(void); \
 /* time.c */ \
 R Y(clock_gettime_seconds)(void); \
 /* error.c: */ \
@@ -877,7 +879,15 @@ void Y(upd_axpy_complex)(C *x, R a, C *y, NFFT_INT n); \
 /** Swaps each half over N[d]/2. */ \
 void Y(fftshift_complex)(C *x, NFFT_INT d, NFFT_INT* N); \
 void Y(fftshift_complex_int)(C *x, int d, int* N); \
-void Y(get_version)(unsigned *major, unsigned *minor, unsigned *patch);
+/** Return library version. */ \
+void Y(get_version)(unsigned *major, unsigned *minor, unsigned *patch); \
+/** \
+ * Return name of window function. \
+ * \
+ * The window function to be used is configured at compile time. \
+ */ \
+const char *Y(get_window_name)(); \
+NFFT_INT Y(get_default_window_cut_off)();
 
 NFFT_DEFINE_UTIL_API(NFFT_MANGLE_FLOAT,float,fftwf_complex)
 NFFT_DEFINE_UTIL_API(NFFT_MANGLE_DOUBLE,double,fftw_complex)
