@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2020 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -725,7 +725,7 @@ void X(trafo)(X(plan) *ths)
         full_psi__A(ths);*/
 
       /* Set \f$ f_j = \sum_{l \in I_n,m(x_j)} g_l \psi\left(x_j-\frac{l}{n}\right)
-       * \text{ for } j=0,\hdots,M-1 \f$ */
+       * \text{ for } j=0,\dots,M-1 \f$ */
       TIC(2)
       B_A(ths);
       TOC(2)
@@ -1034,11 +1034,10 @@ void X(init)(X(plan) *ths, int d, int *N, int M_total)
   {
 //#ifdef _OPENMP
 //    ths->flags = PRE_PHI_HUT | PRE_PSI | MALLOC_X| MALLOC_F_HAT | MALLOC_F |
-//                      FFTW_INIT | FFT_OUT_OF_PLACE | NFFT_SORT_NODES |
-//          NFFT_OMP_BLOCKWISE_ADJOINT;
+//                      FFTW_INIT | NFFT_SORT_NODES | NFFT_OMP_BLOCKWISE_ADJOINT;
 //#else
     ths->flags = PRE_PHI_HUT | PRE_PSI | MALLOC_X| MALLOC_F_HAT | MALLOC_F |
-                      FFTW_INIT | FFT_OUT_OF_PLACE | NFFT_SORT_NODES;
+                      FFTW_INIT | NFFT_SORT_NODES;
 //#endif
   }
   else
@@ -1133,9 +1132,6 @@ const char* X(check)(X(plan) *ths)
 
     if(ths->N[j] - 1 <= ths->m)
       return "Polynomial degree N is smaller than cut-off m";
-
-    if(ths->N[j]%2 == 1)
-      return "polynomial degree N has to be even";
   }
   return 0;
 }
