@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -588,7 +588,8 @@ void nnfft_init_guru(nnfft_plan *ths, int d, int N_total, int M_total, int *N, i
   ths->m= m;
   ths->nnfft_flags= nnfft_flags;
   fftw_flags= FFTW_ESTIMATE| FFTW_DESTROY_INPUT;
-  nfft_flags= PRE_PHI_HUT| MALLOC_F_HAT| FFTW_INIT| FFT_OUT_OF_PLACE| NFFT_OMP_BLOCKWISE_ADJOINT;
+  nfft_flags= PRE_PHI_HUT| MALLOC_F_HAT| FFTW_INIT|
+      ((d == 1) ? FFT_OUT_OF_PLACE : 0U) | NFFT_OMP_BLOCKWISE_ADJOINT;
 
   if(ths->nnfft_flags & PRE_PSI)
     nfft_flags = nfft_flags | PRE_PSI;
@@ -641,7 +642,8 @@ ths->m=WINDOW_HELP_ESTIMATE_m;
   }
 
   ths->nnfft_flags=PRE_PSI| PRE_PHI_HUT| MALLOC_X| MALLOC_V| MALLOC_F_HAT| MALLOC_F;
-  nfft_flags= PRE_PSI| PRE_PHI_HUT| MALLOC_F_HAT| FFTW_INIT| FFT_OUT_OF_PLACE| NFFT_OMP_BLOCKWISE_ADJOINT;
+  nfft_flags= PRE_PSI| PRE_PHI_HUT| MALLOC_F_HAT| FFTW_INIT|
+      ((d == 1) ? FFT_OUT_OF_PLACE : 0U)| NFFT_OMP_BLOCKWISE_ADJOINT;
 
   fftw_flags= FFTW_ESTIMATE| FFTW_DESTROY_INPUT;
   nnfft_init_help(ths,ths->m,nfft_flags,fftw_flags);
