@@ -1,5 +1,5 @@
 
-% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -26,10 +26,9 @@ x=rand(M,1)-0.5; %nodes
 % Initialisation
 plan=nfft(1,N,M); % create plan of class type nfft
 %n=2^(ceil(log(N)/log(2))+1);
-%plan=nfft(1,N,M,n,7,bitor(PRE_PHI_HUT,PRE_PSI),FFTW_MEASURE); % use of nfft_init_guru
+%plan=nfft(1,N,M,n,8,bitor(PRE_PHI_HUT,bitor(PRE_PSI,NFFT_OMP_BLOCKWISE_ADJOINT)),FFTW_MEASURE); % use of nfft_init_guru
 
-plan.x=x; % set nodes in plan
-nfft_precompute_psi(plan); % precomputations
+plan.x=x; % set nodes in plan and perform precomputations
 
 % NFFT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
