@@ -1,7 +1,7 @@
 %NFSFT_PRECOMPUTE Node-independent precomputation (for FPT)
-%   Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+%   Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 
-% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,10 @@
 % this program; if not, write to the Free Software Foundation, Inc., 51
 % Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 function nfsft_precompute(N,kappa,nfsft_flags,fpt_flags)
+if ~exist('kappa','var')
+  kappa = 1000;
+end
+
 if ~exist('nfsft_flags','var')
   nfsft_flags = 0;
 end
