@@ -1,7 +1,6 @@
-%NFSFT_PRECOMPUTE_X Node-dependent precomputation (for NFFT)
-%   Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+%NFSFT_PRECOMPUTE_X Deprecated function.
 
-% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -17,4 +16,5 @@
 % this program; if not, write to the Free Software Foundation, Inc., 51
 % Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 function nfsft_precompute_x(p)
-nfsftmex('precompute_x',p)
+% Do nothing.
+% The functionality has been moved to nfsft_set_x.
