@@ -41,26 +41,13 @@ static int n_max = -1; /* maximum degree precomputed */
 static double kappa_global; /* parameters of percompute */
 static unsigned int nfsft_flags_global = 0U;
 static unsigned int fpt_flags_global = 0U;
+static int nthreads_global = 1;
 static char cmd[CMD_LEN_MAX];
 
-static inline void get_nm(const mxArray *prhs[], int *n, int *m)
-{
-  int t = nfft_mex_get_int(prhs[1],"nfsft: Input argument N must be a scalar.");
-  DM(if (t < 0)
-    mexErrMsgTxt("nfsft: Input argument N must be non-negative.");
-  if (t > n_max)
-    mexErrMsgTxt("nfsft: Input argument N must be <= the degree from nfsft_precompute.");)
-  *n = t;
-  t = nfft_mex_get_int(prhs[2],"nfsft: Input argument M must be a scalar.");
-  DM(if (t < 1)
-    mexErrMsgTxt("nfsft: Input argument M must be positive.");)
-  *m = t;
-}
-
 static inline void get_nmf(const mxArray *prhs[], int *n, int *m,
   unsigned int *f)
 {
-  get_nm(prhs,n,m);
+  nfft_mex_get_nm_odd(prhs,n,m);
   *f = nfft_mex_get_int(prhs[3],"nfsft: Input argument flags must be a scalar.");
 }
 
@@ -77,12 +64,6 @@ static inline void get_nmffc(const mxArray *prhs[], int *n, int *m,
   }
 }
 
-static inline void check_nargs(const int nrhs, const int n, const char* errmsg)
-{
-  DM(if (nrhs != n)
-    mexErrMsgTxt(errmsg);)
-}
-
 static inline void check_plan(int i)
 {
   DM(if (i < 0 || i >= plans_num_allocated || plans[i] == 0)
@@ -116,7 +97,9 @@ static inline int mkplan()
 
 static inline void init_values_zero(nfsft_plan *plan)
 {
-  memset(plan->x, 0U, plan->M_total*2*sizeof(double));
+  // Equispaced nodes are already set in nfsft_init
+  if (!(plan->flags & NFSFT_EQUISPACED))
+    memset(plan->x, 0U, plan->M_total*2*sizeof(double));
   memset(plan->f, 0U, plan->M_total*sizeof(double _Complex));
   memset(plan->f_hat, 0U, plan->N_total*sizeof(double _Complex));
 }
@@ -157,10 +140,8 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
      * which otherwise crashes upon invocation of this mex function. */
     mexEvalString("fft([1,2,3,4]);");
 
-/**  Disabled for performance issues caused by non-thread-safe mxMalloc()
-  *  and many calls of nfft_malloc in nfsft_precompute/fpt_precompute...
-  */
     nfft_mex_install_mem_hooks();
+    nthreads_global = X(get_num_threads)();
 
     mexAtExit(cleanup);
     gflags &= ~NFSFT_MEX_FIRST_CALL;
@@ -178,11 +159,11 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 
   if (strcmp(cmd,"init") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for init.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for init.");
     {
       int i; 
       int n, m;
-      get_nm(prhs,&n,&m);
+      nfft_mex_get_nm_odd(prhs,&n,&m);
       i = mkplan();
       nfsft_init(plans[i],n,m);
       init_values_zero(plans[i]);
@@ -192,7 +173,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"init_advanced") == 0)
   {
-    check_nargs(nrhs,4,"Wrong number of arguments for init_advanced.");
+    nfft_mex_check_nargs(nrhs,4,"Wrong number of arguments for init_advanced.");
     {
       int i;
       int n, m;
@@ -208,7 +189,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"init_guru") == 0)
   {
-    check_nargs(nrhs,6,"Wrong number of arguments for init_guru.");
+    nfft_mex_check_nargs(nrhs,6,"Wrong number of arguments for init_guru.");
     {
       int i;
       int n, m, c;
@@ -224,13 +205,13 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"precompute") == 0)
   {
-    check_nargs(nrhs,5,"Wrong number of arguments for precompute.");
+    nfft_mex_check_nargs(nrhs,5,"Wrong number of arguments for precompute.");
     {
       int n = nfft_mex_get_int(prhs[1],"nfsft: Input argument n must be a scalar.");
       double k = nfft_mex_get_double(prhs[2],"nfsft: Input argument kappa must be a scalar.");
       unsigned int f = nfft_mex_get_int(prhs[3],"nfsft: Input argument flags must be a scalar.");
       unsigned int f2 = nfft_mex_get_int(prhs[4],"nfsft: Input argument flags2 must be a scalar.");
-      if ((n_max < n) || (k != kappa_global) || (f != nfsft_flags_global) || (f2 != fpt_flags_global))
+      if ((n_max < n) || (k != kappa_global) || (f != nfsft_flags_global) || (f2 != fpt_flags_global) || (nthreads_global != X(get_num_threads)()))
       {
         if (gflags & NFSFT_MEX_PRECOMPUTED)
           nfsft_forget();
@@ -247,7 +228,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"forget") == 0)
   {
-    check_nargs(nrhs,1,"Wrong number of arguments for forget.");
+    nfft_mex_check_nargs(nrhs,1,"Wrong number of arguments for forget.");
     nfsft_forget();
     n_max = -1;
     gflags &= ~NFSFT_MEX_PRECOMPUTED;
@@ -255,7 +236,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"trafo") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for trafo.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for trafo.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -265,7 +246,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"adjoint") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for adjoint.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for adjoint.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -275,7 +256,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"finalize") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for finalize.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for finalize.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -293,7 +274,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"trafo_direct") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for trafo direct.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for trafo direct.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -303,7 +284,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"adjoint_direct") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for adjoint direct.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for adjoint direct.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -313,7 +294,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_x") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_x.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_x.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -335,7 +316,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_f") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_f.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_f.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -355,7 +336,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_f_hat") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -376,7 +357,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_f_hat_linear") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat_linear.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat_linear.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -397,15 +378,17 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_x") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_x.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_x.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
       const int m = plans[i]->M_total;
       DM(if (!mxIsDouble(prhs[2]) || mxGetNumberOfDimensions(prhs[2]) > 2)
-        mexErrMsgTxt("Input argument x must be a 2 x M double array");)
+        mexErrMsgTxt("nfsft: Input argument x must be a 2 x M double array");)
       DM(if (mxGetM(prhs[2]) != 2 || mxGetN(prhs[2]) != (unsigned)m)
-        mexErrMsgTxt("Input argument x must have correct size.");)
+        mexErrMsgTxt("nfsft: Input argument x must have correct size.");)
+      DM(if (plans[i]->flags & NFSFT_EQUISPACED)
+        mexErrMsgTxt("nfsft: Equispaced nodes x are set automatically");)
       {
         double *x = mxGetPr(prhs[2]);
         int j;
@@ -421,7 +404,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_f") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_f.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_f.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -443,7 +426,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_f_hat") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -472,7 +455,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_f_hat_linear") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat_linear.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat_linear.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -500,7 +483,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"display") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for set_f_hat_linear.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for set_f_hat_linear.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfsft: Input argument plan must be a scalar.");
       check_plan(i);
@@ -518,12 +501,26 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if(strcmp(cmd,"get_num_threads") == 0)
   {
-    int32_t nthreads = X(get_num_threads)();
-    plhs[0] = mxCreateNumericMatrix(1, 1, mxINT32_CLASS, mxREAL);
-    *((int32_t *)mxGetData(plhs[0])) = nthreads;
+    INT nthreads = X(get_num_threads)();
+    plhs[0] = mxCreateDoubleScalar((double) nthreads);
+    return;
+  }
+  else if(strcmp(cmd,"set_num_threads") == 0)
+  {
+    int nthreads_new = nfft_mex_set_num_threads_check(nrhs, prhs, (void **) plans, plans_num_allocated);
+    DM(if ((gflags & NFSFT_MEX_PRECOMPUTED) && (nthreads_new != nthreads_global))
+      mexWarnMsgIdAndTxt("nfft:set_num_threads:fptAllocated","New number of threads may not affect the FPT step unless you re-run nfsft_precompute.");)
+    X(set_num_threads)(nthreads_new);
+    nthreads_global = nthreads_new;
 
     return;
   }
+  else if(strcmp(cmd,"has_threads_enabled") == 0)
+  {
+    INT threads_enabled = X(has_threads_enabled)();
+    plhs[0] = mxCreateDoubleScalar((double) threads_enabled);
+    return;
+  }
   else
     mexErrMsgTxt("nfsft: Unknown command.\n");
 }
