@@ -1,8 +1,8 @@
 %PROJECTION Example program: Project a function onto spherical harmonics.
 %
-%   Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+%   Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 
-% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -18,7 +18,7 @@
 % this program; if not, write to the Free Software Foundation, Inc., 51
 % Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 function err = projection()
-disp(sprintf('Number of threads: %d\n', nfsft_get_num_threads()));
+fprintf('Number of threads: %d\n', nfsft_get_num_threads());
 % threshold
 kappa = 1000;
 % polynomial degrees
