@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2020 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -34,63 +34,10 @@
 #define NFST_MEX_FIRST_CALL (1U << 0)
 static unsigned short gflags = NFST_MEX_FIRST_CALL;
 
-static nfst_plan** plans = NULL; /* plans */
+static NFST(plan)** plans = NULL; /* plans */
 static unsigned int plans_num_allocated = 0;
 static char cmd[CMD_LEN_MAX];
 
-static inline void get_nm(const mxArray *prhs[], int *n, int *m)
-{
-  int t = nfft_mex_get_int(prhs[1],"nfst: Input argument N must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N must be non-negative and multiple of two.");)
-  *n = t;
-  t = nfft_mex_get_int(prhs[2],"nfst: Input argument M must be a scalar.");
-  DM(if (t < 1)
-    mexErrMsgTxt("nfst: Input argument M must be positive.");)
-  *m = t;
-}
-
-static inline void get_n1n2m(const mxArray *prhs[], int *n1, int *n2, int *m)
-{
-  int t = nfft_mex_get_int(prhs[1],"nfst: Input argument N1 must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N1 must be non-negative and even.");)
-  *n1 = t;
-
-  t = nfft_mex_get_int(prhs[2],"nfst: Input argument N2 must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N2 must be non-negative and even.");)
-  *n2 = t;
-
-  t = nfft_mex_get_int(prhs[3],"nfst: Input argument M must be a scalar.");
-  DM(if (t < 1)
-    mexErrMsgTxt("nfst: Input argument M must be positive.");)
-  *m = t;
-}
-
-static inline void get_n1n2n3m(const mxArray *prhs[], int *n1, int *n2, int *n3, int *m)
-{
-  int t = nfft_mex_get_int(prhs[1],"nfst: Input argument N1 must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N1 must be non-negative and even.");)
-  *n1 = t;
-
-  t = nfft_mex_get_int(prhs[2],"nfst: Input argument N2 must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N2 must be non-negative and even.");)
-  *n2 = t;
-
-  t = nfft_mex_get_int(prhs[3],"nfst: Input argument N3 must be a scalar.");
-  DM(if ((t < 0) || (t%2!=0))
-    mexErrMsgTxt("nfst: Input argument N3 must be non-negative and even.");)
-  *n3 = t;
-
-  t = nfft_mex_get_int(prhs[4],"nfst: Input argument M must be a scalar.");
-  DM(if (t < 1)
-    mexErrMsgTxt("nfst: Input argument M must be positive.");)
-  *m = t;
-}
-
 static inline void get_guru(const mxArray *prhs[], int d, int *N, int *M, int *n, int *m, unsigned int *f1, unsigned int *f2)
 {
   /** NO ERROR HANDLING !!*/
@@ -111,12 +58,6 @@ static inline void get_guru(const mxArray *prhs[], int d, int *N, int *M, int *n
   *f2 = mxGetScalar(mxGetCell(prhs[1], (unsigned int)(2*d+4)));
 }
 
-static inline void check_nargs(const int nrhs, const int n, const char* errmsg)
-{
-  DM(if (nrhs != n)
-    mexErrMsgTxt(errmsg);)
-}
-
 static inline void check_plan(int i)
 {
   DM(if (i < 0 || i >= plans_num_allocated || plans[i] == 0)
@@ -134,17 +75,17 @@ static inline int mkplan(void)
     if (plans_num_allocated >= INT_MAX - PLANS_START - 1)
       mexErrMsgTxt("nsft: Too many plans already allocated.");
 
-    nfst_plan** plans_old = plans;
-    plans = nfft_malloc((plans_num_allocated+PLANS_START)*sizeof(nfst_plan*));
+    NFST(plan)** plans_old = plans;
+    plans = X(malloc)((plans_num_allocated+PLANS_START)*sizeof(NFST(plan)*));
     for (l = 0; l < plans_num_allocated; l++)
       plans[l] = plans_old[l];
     for (l = plans_num_allocated; l < plans_num_allocated+PLANS_START; l++)
       plans[l] = 0;
     if (plans_num_allocated > 0)
-      nfft_free(plans_old);
+      X(free)(plans_old);
     plans_num_allocated += PLANS_START;
   }
-  plans[i] = nfft_malloc(sizeof(nfst_plan));
+  plans[i] = X(malloc)(sizeof(NFST(plan)));
   return i;
 }
 
@@ -158,14 +99,14 @@ static void cleanup(void)
     for (i = 0; i < plans_num_allocated; i++)
       if (plans[i])
       {
-        nfst_finalize(plans[i]);
-	nfft_free(plans[i]);
+        NFST(finalize)(plans[i]);
+	X(free)(plans[i]);
         plans[i] = NULL;
       }
 
     if (plans_num_allocated > 0)
     {
-      nfft_free(plans);
+      X(free)(plans);
       plans = NULL;
       plans_num_allocated = 0;
     }
@@ -199,39 +140,39 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 
   if (strcmp(cmd,"init_1d") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for init.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for init.");
     {
       int i;
       int n, m;
-      get_nm(prhs,&n,&m);
+      nfft_mex_get_nm_odd(prhs,&n,&m);
       i = mkplan();
-      nfst_init_1d(plans[i],n,m);
+      NFST(init_1d)(plans[i],n,m);
       plhs[0] = mxCreateDoubleScalar((double)i);
     }
     return;
   }
   else if (strcmp(cmd,"init_2d") == 0)
   {
-    check_nargs(nrhs,4,"Wrong number of arguments for init.");
+    nfft_mex_check_nargs(nrhs,4,"Wrong number of arguments for init.");
     {
       int i;
       int n1, n2, m;
-      get_n1n2m(prhs,&n1,&n2,&m);
+      nfft_mex_get_n1n2m_odd(prhs,&n1,&n2,&m);
       i = mkplan();
-      nfst_init_2d(plans[i],n1,n2,m);
+      NFST(init_2d)(plans[i],n1,n2,m);
       plhs[0] = mxCreateDoubleScalar((double)i);
     }
     return;
   }
   else if (strcmp(cmd,"init_3d") == 0)
   {
-    check_nargs(nrhs,5,"Wrong number of arguments for init.");
+    nfft_mex_check_nargs(nrhs,5,"Wrong number of arguments for init.");
     {
       int i;
       int n1, n2, n3, m;
-      get_n1n2n3m(prhs,&n1,&n2,&n3,&m);
+      nfft_mex_get_n1n2n3m_odd(prhs,&n1,&n2,&n3,&m);
       i = mkplan();
-      nfst_init_3d(plans[i],n1,n2,n3,m);
+      NFST(init_3d)(plans[i],n1,n2,n3,m);
       plhs[0] = mxCreateDoubleScalar((double)i);
     }
     return;
@@ -250,7 +191,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 
     get_guru(prhs,d,N,&M,n,&m,&f1,&f2);
     i = mkplan();
-    nfst_init_guru(plans[i],d,N,M,n,m,
+    NFST(init_guru)(plans[i],d,N,M,n,m,
 		   f1 | MALLOC_X | MALLOC_F | MALLOC_F_HAT | FFTW_INIT,
 		   f2);
 
@@ -261,7 +202,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   else if (strcmp(cmd,"precompute_psi") == 0)
   {
     mexErrMsgTxt("not implemented, precompute_psi is already called in set_x");
-/*    check_nargs(nrhs,2,"Wrong number of arguments for precompute_psi.");
+/*    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for precompute_psi.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
@@ -272,59 +213,59 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"trafo") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for trafo.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for trafo.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
-      nfst_trafo(plans[i]);
+      NFST(trafo)(plans[i]);
     }
     return;
   }
   else if (strcmp(cmd,"adjoint") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for adjoint.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for adjoint.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
-      nfst_adjoint(plans[i]);
+      NFST(adjoint)(plans[i]);
     }
     return;
   }
   else if (strcmp(cmd,"finalize") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for finalize.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for finalize.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
-      nfst_finalize(plans[i]);
-      nfft_free(plans[i]);
+      NFST(finalize)(plans[i]);
+      X(free)(plans[i]);
       plans[i] = 0;
     }
     return;
   }
   else if (strcmp(cmd,"trafo_direct") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for trafo direct.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for trafo direct.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
-      nfst_trafo_direct(plans[i]);
+      NFST(trafo_direct)(plans[i]);
     }
     return;
   }
   else if (strcmp(cmd,"adjoint_direct") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for adjoint direct.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for adjoint direct.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       check_plan(i);
-      nfst_adjoint_direct(plans[i]);
+      NFST(adjoint_direct)(plans[i]);
     }
     return;
   }
   else if (strcmp(cmd,"get_x") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_x.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_x.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int m, d;
@@ -344,7 +285,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_f") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_f.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_f.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int m;
@@ -364,7 +305,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"get_f_hat") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for get_f_hat.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int n;
@@ -384,7 +325,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_x") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_x.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_x.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int m, d;
@@ -406,13 +347,13 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 	    plans[i]->x[d*j+t] = x[d*j+t];
 	  }
       }
-      nfst_precompute_one_psi(plans[i]);
+      NFST(precompute_one_psi)(plans[i]);
     }
     return;
   }
   else if (strcmp(cmd,"set_f") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_f.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_f.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int m;
@@ -433,7 +374,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"set_f_hat") == 0)
   {
-    check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat.");
+    nfft_mex_check_nargs(nrhs,3,"Wrong number of arguments for set_f_hat.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       int n;
@@ -456,7 +397,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if (strcmp(cmd,"display") == 0)
   {
-    check_nargs(nrhs,2,"Wrong number of arguments for set_f_hat_linear.");
+    nfft_mex_check_nargs(nrhs,2,"Wrong number of arguments for set_f_hat_linear.");
     {
       int i = nfft_mex_get_int(prhs[1],"nfst: Input argument plan must be a scalar.");
       mexPrintf("Plan %d\n",i);
@@ -474,12 +415,23 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   }
   else if(strcmp(cmd,"get_num_threads") == 0)
   {
-    int32_t nthreads = X(get_num_threads)();
-    plhs[0] = mxCreateNumericMatrix(1, 1, mxINT32_CLASS, mxREAL);
-    *((int32_t *)mxGetData(plhs[0])) = nthreads;
+    INT nthreads = X(get_num_threads)();
+    plhs[0] = mxCreateDoubleScalar((double) nthreads);
+    return;
+  }
+  else if(strcmp(cmd,"set_num_threads") == 0)
+  {
+    int nthreads_new = nfft_mex_set_num_threads_check(nrhs, prhs, (void **) plans, plans_num_allocated);
+    X(set_num_threads)(nthreads_new);
 
     return;
   }
+  else if(strcmp(cmd,"has_threads_enabled") == 0)
+  {
+    INT threads_enabled = X(has_threads_enabled)();
+    plhs[0] = mxCreateDoubleScalar((double) threads_enabled);
+    return;
+  }
   else
     mexErrMsgTxt("nfst: Unknown command.\n");
 }
