@@ -1,5 +1,5 @@
 
-% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2017 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -15,7 +15,7 @@
 % this program; if not, write to the Free Software Foundation, Inc., 51
 % Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-% This class provides robust a Matlab interface to the NFFT library.
+% This class provides a Matlab interface to the NNFFT module.
 %
 % Examples
 %   See Matlab scripts test_nnfft*d.m.
@@ -135,6 +135,7 @@ function delete(h)
 % Destructor
 	if(h.plan_is_set)
 		nnfftmex('finalize',h.plan);
+		h.plan_is_set=false;
 	end %if
 end %function
 
